@@ -503,10 +503,6 @@ class TabBar(QTabBar):
             # We return it directly rather than setting `size' because we don't
             # want to ensure it's valid in this special case.
             return QSize()
-        elif self.count() * minimum_size.width() > self.width():
-            # If we don't have enough space, we return the minimum size so we
-            # get scroll buttons as soon as needed.
-            size = minimum_size
         else:
             tab_width_pinned_conf = config.get('tabs', 'pinned-width')
 
@@ -517,19 +513,21 @@ class TabBar(QTabBar):
 
             no_pinned_count = self.count() - self.pinned_count
             pinned_width = tab_width_pinned_conf * self.pinned_count
-            no_pinned_width = self.width() - pinned_width
+            # Prevent any tabs from being smaller than the min size
+            no_pinned_width = max(self.width() - pinned_width,
+                                  minimum_size.width() * no_pinned_count)
 
             if pinned:
                 width = tab_width_pinned_conf
             else:
 
-                # If we *do* have enough space, tabs should occupy the whole
-                # window width. If there are pinned tabs their size will be
-                # subtracted from the total window width.
-                # During shutdown the self.count goes down,
-                # but the self.pinned_count not - this generates some odd
+                # Tabs should attempt to occupy the whole window width. If
+                # there are pinned tabs their size will be subtracted from the
+                # total window width.  During shutdown the self.count goes
+                # down, but the self.pinned_count not - this generates some odd
                 # behavior. To avoid this we compare self.count against
-                # self.pinned_count.
+                # self.pinned_count. If we end up having too little space, we
+                # set the minimum size below.
                 if self.pinned_count > 0 and no_pinned_count > 0:
                     width = no_pinned_width / no_pinned_count
                 else:
@@ -541,6 +539,10 @@ class TabBar(QTabBar):
                     index < no_pinned_width % no_pinned_count):
                 width += 1
 
+            # If we don't have enough space, we return the minimum size so we
+            # get scroll buttons as soon as needed.
+            width = max(width, minimum_size.width())
+
             size = QSize(width, height)
         qtutils.ensure_valid(size)
         return size
@@ -761,6 +763,17 @@ class TabBarStyle(QCommonStyle):
             rct = super().subElementRect(sr, opt, widget)
             return rct
         else:
+            try:
+                # We need this so the left scroll button is aligned properly.
+                # Otherwise, empty space will be shown after the last tab even
+                # though the button width is set to 0
+                #
+                # QStyle.SE_TabBarScrollLeftButton was added in Qt 5.7
+                if sr == QStyle.SE_TabBarScrollLeftButton:
+                    return super().subElementRect(sr, opt, widget)
+            except AttributeError:
+                pass
+
             return self._style.subElementRect(sr, opt, widget)
 
     def _tab_layout(self, opt):
